@@ -968,12 +968,12 @@ static const char *pyType(sipSpec *pt, argDef *ad, int sec, classDef **scope)
         if (sec)
             type_name = "callable";
         else
-            type_name = TQOBJECT_OBJECT_NAME_STRING;
+            type_name = "TQObject";
 
         break;
 
     case tqobject_type:
-        type_name = TQOBJECT_OBJECT_NAME_STRING;
+        type_name = "TQObject";
         break;
 
     case ustring_type:
